# -*- coding: iso-8859-1 -*-
"""
    MoinMoin - ep2008 (EuroPython 2008) theme

    @copyright: 2003-2007 by Nir Soffer, Thomas Waldmann, Paul Boddie
    @license: GNU GPL, see COPYING for details.
"""

from MoinMoin.theme import ThemeBase
from MoinMoin.action import AttachFile
import random

class Theme(ThemeBase):

    name = "ep2008"

    def header(self, d, **kw):
        """ Assemble wiki header

        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """
        html = [
            # Pre header custom html
            self.emit_custom_html(self.cfg.page_header1),

            # Header
            u'<div id="header">',
            self.logo(),

            # Banner
            self.banner(d),

            self.searchform(d),
            self.navibar(d),
            self.msg(d),

            # NOTE: Hack everything into the header
            u'<div id="end-of-header">',
            u'</div>',
            u'</div>',

            # Post header custom html (not recommended)
            self.emit_custom_html(self.cfg.page_header2),

            # Start of page
            u'<div class="page-%s">' % d['page_name'],
            self.startPage(),
        ]
        return u'\n'.join(html)

    def editorheader(self, d, **kw):
        """ Assemble wiki header for editor

        @param d: parameter dictionary
        @rtype: unicode
        @return: page header html
        """
        html = [
            # Pre header custom html
            self.emit_custom_html(self.cfg.page_header1),

            # Header
            u'<div id="header">',
            self.title(d),
            self.msg(d),
            u'</div>',

            # Post header custom html (not recommended)
            self.emit_custom_html(self.cfg.page_header2),

            # Start of page
            u'<div class="page-%s">' % d['page_name'],
            self.startPage(),
        ]
        return u'\n'.join(html)

    def footer(self, d, **keywords):
        """ Assemble wiki footer

        @param d: parameter dictionary
        @keyword ...:...
        @rtype: unicode
        @return: page footer html
        """
        page = d['page']

        if self.cfg.special_username:
            username = self.specialUsername(d)
        else:
            username = self.username(d)

        html = [
            # End of page
            self.pageinfo(page),
            self.endPage(),
            u'</div>',

            # Pre footer custom html (not recommended!)
            self.emit_custom_html(self.cfg.page_footer1),

            # Footer
            u'<div id="footer">',
            self.cfg.contact_string,
            u'<div id="contribute">',
            #self.cfg.contribute_string,
            #u'<div class="contribute-hidden">',
            #self.username(d),
            #u'<div id="locationline">',
            #self.interwiki(d),
            #self.title(d),
            #u'</div>',
            username,
            self.editbar(d),
            self.trail(d),
            #u'</div>',
            u'</div>',
            self.credits(d),
            self.showversion(d, **keywords),
            u'</div>',

            # Post footer custom html
            self.emit_custom_html(self.cfg.page_footer2),
            ]
        return u'\n'.join(html)

    def editbarItems(self, page):
        """ Return list of items to show on the editbar

        This is separate method to make it easy to customize the
        editbar in sub classes.
        """

        request = self.request

        items = [self.editorLink(page),
                self.infoLink(page),
                self.subscribeLink(page),
                self.quicklinkLink(page),]

        if page.isWritable() and request.user.valid and request.user.may.write(page.page_name):
            items.append(self.attachmentsLink(page))

        if request.user.valid:
            items.append(self.actionsMenu(page))

        return items

    def specialUsername(self, d):
        request = self.request
        _ = request.getText

        if request.user.valid and request.user.name:
            return u'<div class="username">%s</div>' % request.formatter.text(request.user.name)
        else:
            # NOTE: Using the contribute string!
            return u'<div class="no-username">%s</div>' % \
                d['page'].link_to(request, text=self.cfg.contribute_string,
                                  querystr={'action': 'login'}, id="login")

    def banner(self, d):
        request = self.request
        formatter = request.formatter

        # Either get banners per page or acquire them from a central source.

        if self.cfg.banner_per_page:
            pagename = d["page"].page_name
        else:
            pagename = self.cfg.banner_attachment_page

        # Only get attachments with a certain prefix.

        attachments = []
        for filename in AttachFile._get_files(request, pagename):
            if filename.startswith(self.cfg.banner_prefix):
                attachments.append(filename)

        # Display the default banner if no attachments are found.

        target = self.cfg.banner_link_page

        if not attachments:
            return "%s%s%s" % (formatter.pagelink(1, target),
                               self.cfg.banner_string,
                               formatter.pagelink(0))

        # Choose an attachment at random and return the HTML to show it.

        attachment = random.choice(attachments)

        kw = {}
        kw['src'] = AttachFile.getAttachUrl(pagename, attachment, request)
        kw['alt'] = self.cfg.banner_alt_text
        kw['id'] = u'banner'

        return "%s%s%s" % (formatter.pagelink(1, target),
                           formatter.image(**kw),
                           formatter.pagelink(0))

def execute(request):
    """
    Generate and return a theme object

    @param request: the request object
    @rtype: MoinTheme
    @return: Theme object
    """
    return Theme(request)

# vim: tabstop=4 expandtab shiftwidth=4
